import assert from 'assert';
import { join } from 'path';
import * as fs from 'fs-extra';
import debounce from 'lodash/debounce';
import * as esbuild from 'esbuild';
import { Service } from './core';
export class Bootstrap {
  constructor() {
    this.debounceRun = debounce(() => {
      this.run();
    }, 1500);
    this.server = new Service({
      paths: {
        cwd: process.cwd()
      }
    });
  }

  getConfig() {
    assert(fs.existsSync(this.userConfigFilePath), '请在根目录上创建配置文件');
    const configTemporaryFilePath = this.server.resolveTmpPath(`config.js`);
    esbuild.buildSync({
      entryPoints: [this.userConfigFilePath],
      bundle: true,
      platform: 'node',
      treeShaking: true,
      outfile: configTemporaryFilePath
    });
    delete require.cache[require.resolve(configTemporaryFilePath)];
    return require(configTemporaryFilePath).default;
  }

  init() {
    const cwd = process.cwd();
    this.userConfigPath = join(cwd, 'config');
    this.userConfigFilePath = join(this.userConfigPath, `index.ts`);
    const userConfig = this.getConfig();
    this.server.setEnv(userConfig.env || process.env.NODE_ENV || 'development').setUserConfig(userConfig);
    return this.server.plugin.initPlugins();
  }

  getServer() {
    return this.server;
  }

  async run(isReCompile = true) {
    this.server.logger.printCompiling();

    if (isReCompile) {
      this.server.setUserConfig(this.getConfig());
    }

    await this.server.run(isReCompile);
    this.server.logger.stopAndPersistOk('生成配置完成');
    setTimeout(() => {
      this.server.logger.printWhenFirstDone();
    });
  }

}