import { outputFile } from 'fs-extra';
import { GenerateAppEntryFile } from './GenerateAppEntryFile';
import { registerMethodKeys } from './constants';
export const stage = -9;

function addStrictModeRender(api) {
  const isSkip = () => api.userConfig.strictMode !== true;

  api.addImportToAppEntryFile({
    isSkip,
    fn: () => ({
      specifier: '{ StrictMode }',
      source: 'react'
    })
  });
  api.addContainerRenderToAppEntryFile({
    stage: 998,
    isSkip,
    fn: () => `
function renderStrictMode(children?: React.ReactElement) {
  return <StrictMode>{children}</StrictMode>;
}`
  });
}

function addRootContainer(api) {
  api.addImportToAppEntryFile(() => ({
    specifier: 'ReactDOM',
    source: 'react-dom'
  }));
  api.addImportToAppEntryFile(() => ({
    specifier: '{ isFn }',
    source: '@spark-build/web-utils'
  }));
  api.addContainerRenderToAppEntryFile({
    stage: 999,
    fn: () => `
function ReactDOMContainer(ele: React.ReactElement) {
  ReactDOM.render(ele, document.getElementById('root'));
}`
  });
}

export default async function AppEntryFile(api) {
  api.registerMethod({
    name: 'onGenerateAppEntryFile'
  });
  Object.keys(registerMethodKeys).forEach(name => {
    api.registerMethod({
      name
    });
  });
  addStrictModeRender(api);
  addRootContainer(api);
  api.onGenerateAppEntryFile(async () => {
    const filePath = api.resolveSrcPath('main.tsx');
    const content = await GenerateAppEntryFile.run(api);
    return outputFile(filePath, content).then(() => api.prettier.addPrettierFile(filePath));
  });
}