import { join } from 'path';
import { existsSync, readFileSync, outputFile, remove, copy } from 'fs-extra';
import * as Mustache from 'mustache';
export class GenerateFile {
  constructor(server) {
    this.generateFileQueue = [];
    this.server = server;
  }

  addGenerateFileToQueue(opt) {
    this.generateFileQueue.push(opt);
    return this;
  }

  copyFile(src, dest) {
    return copy(src, dest);
  }

  readTplFile(...filePath) {
    return readFileSync(join(...filePath), 'utf-8');
  }

  renderTpl(content, view) {
    return Mustache.render(content, view);
  }

  outputFile(f, c) {
    return outputFile(f, c, 'utf-8');
  }

  async runGenerateFileQueue() {
    if (!this.generateFileQueue.length) {
      return undefined;
    }

    return Promise.all(this.generateFileQueue.map(item => this.outputFile(item.path, item.content))).then(() => {
      this.generateFileQueue = [];
    });
  }

  async removeTmpFile(path) {
    const filePath = this.server.resolveTmpPath(path);
    return existsSync(filePath) ? remove(filePath) : true;
  }

  async writeFile({
    path,
    content,
    isPrettier
  }) {
    const filePath = this.server.resolveTmpPath(path);

    if (existsSync(filePath) && readFileSync(filePath, 'utf-8') === content) {
      return false;
    }

    await this.outputFile(filePath, content);

    if (isPrettier) {
      this.server.prettier.addPrettierFile(filePath);
    }

    return true;
  }

}