import react from '@vitejs/plugin-react';
import WindiCSS from 'vite-plugin-windicss';
import styleImportPlugin from 'vite-plugin-style-import';
import VitePluginCertificate from 'vite-plugin-mkcert';
import { reactAutoConfigPluginConfig } from './reactAutoConfig';
import { Bootstrap } from './Bootstrap';
export const reactAutoConfig = async (options = {}) => {
  const bootstrap = new Bootstrap();
  await bootstrap.init();
  const {
    userConfig
  } = bootstrap.getServer();
  const plugins = [react(options.react), reactAutoConfigPluginConfig(bootstrap)];

  if (userConfig.antd) {
    const {
      styleImport
    } = options;
    plugins.push(styleImportPlugin({ ...(styleImport || {}),
      libs: [{
        libraryName: 'antd',
        esModule: true,
        resolveStyle: name => `antd/es/${name}/style/index`
      }, {
        libraryName: '@ant-design/icons',
        libraryNameChangeCase: 'pascalCase',
        resolveComponent: name => `@ant-design/icons/es/icons/${name}`
      }, ...((styleImport === null || styleImport === void 0 ? void 0 : styleImport.libs) || [])]
    }));
  }

  if (userConfig.mkcert) {
    plugins.push(VitePluginCertificate({
      source: 'coding',
      ...options.mkcert
    }));
  }

  if (userConfig.windiCSS) {
    plugins.push(WindiCSS());
  }

  return plugins;
};