"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Bootstrap = void 0;

var _assert = _interopRequireDefault(require("assert"));

var _path = require("path");

var fs = _interopRequireWildcard(require("fs-extra"));

var _debounce = _interopRequireDefault(require("lodash/debounce"));

var esbuild = _interopRequireWildcard(require("esbuild"));

var _core = require("./core");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Bootstrap {
  constructor() {
    this.debounceRun = (0, _debounce.default)(() => {
      this.run();
    }, 1500);
    this.server = new _core.Service({
      paths: {
        cwd: process.cwd()
      }
    });
  }

  getConfig() {
    (0, _assert.default)(fs.existsSync(this.userConfigFilePath), '请在根目录上创建配置文件');
    const configTemporaryFilePath = this.server.resolveTmpPath(`config.js`);
    esbuild.buildSync({
      entryPoints: [this.userConfigFilePath],
      bundle: true,
      platform: 'node',
      treeShaking: true,
      outfile: configTemporaryFilePath
    });
    delete require.cache[require.resolve(configTemporaryFilePath)];
    return require(configTemporaryFilePath).default;
  }

  init() {
    const cwd = process.cwd();
    this.userConfigPath = (0, _path.join)(cwd, 'config');
    this.userConfigFilePath = (0, _path.join)(this.userConfigPath, `index.ts`);
    const userConfig = this.getConfig();
    this.server.setEnv(userConfig.env || process.env.NODE_ENV || 'development').setUserConfig(userConfig);
    return this.server.plugin.initPlugins();
  }

  getServer() {
    return this.server;
  }

  async run(isReCompile = true) {
    this.server.logger.printCompiling();

    if (isReCompile) {
      this.server.setUserConfig(this.getConfig());
    }

    await this.server.run(isReCompile);
    this.server.logger.stopAndPersistOk('生成配置完成');
    setTimeout(() => {
      this.server.logger.printWhenFirstDone();
    });
  }

}

exports.Bootstrap = Bootstrap;