"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = generateRouter;

var _path = require("path");

var _routes = require("./routes");

var _renderAppRouter = require("./renderAppRouter");

var _generateRouterHelper = require("./generateRouterHelper");

const dTsFilePath = '@types/index.d.ts';

async function generateRouter(api) {
  api.addDepsEntryExports(() => ({
    source: 'react-router-dom'
  }));
  api.addImportToAppEntryFile(() => ({
    specifier: '{ BrowserRouter as Router }',
    source: 'react-router-dom'
  }));
  api.addImportToAppEntryFile(() => ({
    specifier: '{ RenderAppRouter }',
    source: api.resolveConfigAliasNamePath(_renderAppRouter.filePath.replace('.tsx', ''))
  }));
  api.addContainerRenderToAppEntryFile(() => `
function renderRouter(children?: React.ReactElement) {
  return (
    <Router>
      <RenderAppRouter />

      {children}
    </Router>
  );
}`);
  api.onGenerateFiles(async () => {
    await (0, _routes.generateRoutes)(api);
    await (0, _renderAppRouter.generateRenderAppRouter)(api);
    await (0, _generateRouterHelper.generateRouterHelper)(api);
    await api.generateFile.copyFile((0, _path.join)(__dirname, '../../typings/common.d.ts'), api.resolveTmpPath(dTsFilePath));
  });
}