"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PrettierFiles = void 0;

var fs = _interopRequireWildcard(require("fs-extra"));

var _util = require("../../util");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

class PrettierFiles {
  constructor(server) {
    this.files = [];
    this.isConsoleLog = true;
    this.server = server;
  }

  setConsoleLog(t) {
    this.isConsoleLog = t;
    return this;
  }

  addPrettierFile(file) {
    this.files.push(file);
    return this;
  }

  reset() {
    this.files = [];
  }

  async isExistSparkBuildLintDep() {
    const pkg = await fs.readJson(this.server.resolveRootPath('package.json'));
    const deps = pkg.devDependencies || pkg.dependencies;
    return (deps === null || deps === void 0 ? void 0 : deps['@spark-build/lint']) ? Promise.resolve() : Promise.reject();
  }

  async isExistPrettierFile() {
    const rootFiles = await fs.readdir(this.server.paths.cwd);
    return new Promise((r, j) => {
      rootFiles.some(n => n.indexOf('prettier') !== -1) ? r(undefined) : j();
    });
  }

  async canItBePrettier() {
    return this.isExistPrettierFile();
  }

  prettier(filePath) {
    return (0, _util.exec)(`yarn prettier --config .prettierrc.js --write ${filePath}`, this.isConsoleLog);
  }

  async run() {
    if (!this.files.length) {
      return undefined;
    }

    return this.canItBePrettier().then(() => Promise.all([...new Set(this.files)].map(f => this.prettier(f)))).then(() => this.reset()).catch(() => {});
  }

}

exports.PrettierFiles = PrettierFiles;